pub struct IdentityGateNode {
id: NodeId,
num_vars: usize,
num_dataparallel_vars: Option<usize>,
nonzero_gates: Vec<(u32, u32)>,
pre_routed_data: NodeId,
}Expand description
A node that represents an identity gate in the circuit i.e. that wires values unmodified from one layer to another.
Fields
id: NodeIdnum_vars: usizenum_dataparallel_vars: Option<usize>nonzero_gates: Vec<(u32, u32)>pre_routed_data: NodeIdImplementations
Sourceimpl IdentityGateNode
impl IdentityGateNode
Sourcepub fn new(
pre_routed_data: &dyn CircuitNode,
nonzero_gates: Vec<(u32, u32)>,
num_vars: usize,
num_dataparallel_vars: Option<usize>,
) -> Self
pub fn new( pre_routed_data: &dyn CircuitNode, nonzero_gates: Vec<(u32, u32)>, num_vars: usize, num_dataparallel_vars: Option<usize>, ) -> Self
Constructs a new IdentityGateNode. Arguments:
pre_routed_data: The Node that is being routed to this layer.nonzero_gates: A list of tuples representing the gates that are nonzero, in the form(dest_idx, src_idx).num_vars: The total number of variables in the layer.num_dataparallel_vars: The number of dataparallel variables to use in this layer.